package xyz.lychee.lagfixer.menu;

import com.google.common.collect.Lists;
import com.google.common.collect.UnmodifiableIterator;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;
import org.bukkit.Material;
import org.bukkit.command.CommandSender;
import org.bukkit.configuration.MemorySection;
import org.bukkit.entity.HumanEntity;
import org.bukkit.event.inventory.InventoryClickEvent;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.ItemMeta;
import xyz.lychee.lagfixer.LagFixer;
import xyz.lychee.lagfixer.Language;
import xyz.lychee.lagfixer.managers.CommandManager;
import xyz.lychee.lagfixer.managers.ModuleManager;
import xyz.lychee.lagfixer.managers.SupportManager;
import xyz.lychee.lagfixer.objects.AbstractMenu;
import xyz.lychee.lagfixer.objects.AbstractModule;
import xyz.lychee.lagfixer.utils.MessageUtils;

public class ModulesMenu extends AbstractMenu {
   public ModulesMenu(LagFixer plugin, int size, String title) {
      super(plugin, size, title, false, true);
   }

   public void update() {
      this.getInv().clear();
      this.surroundInventory();
      ModuleManager.getInstance().getModules().values().stream().sorted(Comparator.comparing(AbstractModule::getName)).forEach((module) -> {
         ItemStack imodule = module.getBaseSkull().clone();
         SupportManager.getInstance().getNms().setNBTValue(imodule, "module", module.getClass().getCanonicalName());
         ItemMeta meta = imodule.getItemMeta();
         if (meta != null) {
            meta.setDisplayName(MessageUtils.fixColors((CommandSender)null, "&6&l⭐ &f&lModule: &e&l" + module.getName()));
            List<String> lore = Lists.newArrayList(new String[]{" &8{*} &7Status: " + (module.isLoaded() ? "&a&lENABLED" : "&c&lDISABLED"), " &8{*} &7Customizable values: &e" + module.getSection().getValues(true).values().stream().filter((obj) -> {
               return !(obj instanceof MemorySection);
            }).count(), " &8{*} &7Performance: " + Language.getSerializer().serialize(module.getImpact().getComponent()), "", "&b&nClick to modify configuration!", "", "&eDescription:"});
            UnmodifiableIterator var5 = module.getDescription().iterator();

            while(var5.hasNext()) {
               String line = (String)var5.next();
               StringBuilder lineBuilder = new StringBuilder(" &8{*} &7");
               int wordCount = 0;
               String[] var9 = line.split("\\s+");
               int var10 = var9.length;

               for(int var11 = 0; var11 < var10; ++var11) {
                  String word = var9[var11];
                  if (wordCount < 5 && lineBuilder.length() < 40) {
                     lineBuilder.append(word).append(' ');
                     ++wordCount;
                  } else {
                     lore.add(lineBuilder.toString().trim());
                     lineBuilder = (new StringBuilder("&7")).append(word).append(' ');
                     wordCount = 1;
                  }
               }

               if (lineBuilder.length() != 0) {
                  lore.add(lineBuilder.toString().trim());
               }
            }

            meta.setLore((List)lore.stream().map((str) -> {
               return MessageUtils.fixColors((CommandSender)null, str);
            }).collect(Collectors.toList()));
            imodule.setItemMeta(meta);
         }

         this.getInv().addItem(new ItemStack[]{imodule});
      });
      this.fillInventory();
   }

   public void handleClick(InventoryClickEvent e, ItemStack item) {
      if (item.getType() == Material.PLAYER_HEAD) {
         HumanEntity human = e.getWhoClicked();
         String name = SupportManager.getInstance().getNms().getNBTValue(e.getCurrentItem(), "module");

         try {
            AbstractModule module = ModuleManager.getInstance().get(Class.forName(name));
            if (module == null) {
               human.closeInventory();
               MessageUtils.sendMessage(true, human, "Unknown module with class: " + name);
               return;
            }

            human.openInventory(module.getMenu().getInv());
         } catch (ClassNotFoundException var6) {
            ClassNotFoundException ex = var6;
            human.closeInventory();
            this.getPlugin().printError(ex);
         }
      }

   }

   public AbstractMenu previousMenu() {
      return CommandManager.getInstance().getMainMenu();
   }
}
